@@ -29,10 +29,11 @@ def get_args():
   args = sys.argv
   print(args)
   args.pop(0)
+  print('test-1')
   return args
 
 def is_args_valid(args):
-  print('test')
+  print('test-2')
   valid_args =  all(arg in valid_args_list for arg in args)
   return valid_args
 
